@@ -97,7 +97,7 @@
     <message>
         <location filename="../devicewidget.ui" line="69"/>
         <source>Lock channels together</source>
-        <translation>Kanalen tezamen vergrendelen</translation>
+        <translation>Alle kanalen vergrendelen</translation>
     </message>
     <message>
         <location filename="../devicewidget.ui" line="85"/>
@@ -177,7 +177,7 @@
     <message>
         <location filename="../devicewidget.cc" line="234"/>
         <source>Rename device %1 to:</source>
-        <translation>Apparaatnaam &apos;%1&apos; wijzigen in:</translation>
+        <translation>Apparaatnaam “%1” wijzigen in:</translation>
     </message>
     <message>
         <location filename="../devicewidget.cc" line="241"/>
@@ -386,7 +386,7 @@
     <message>
         <location filename="../pavucontrol.cc" line="110"/>
         <source>Sink callback failure</source>
-        <translation>&apos;Sink callback&apos;-fout</translation>
+        <translation>‘Sink callback’-fout</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="133"/>
@@ -521,32 +521,32 @@
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="607"/>
-        <location filename="../pavucontrol.cc" line="664"/>
+        <location filename="../pavucontrol.cc" line="663"/>
         <source>PulseAudio Volume Control</source>
         <translation>PulseAudio-volumeregeling</translation>
     </message>
     <message>
         <location filename="../pavucontrol.cc" line="622"/>
         <source>Connection to PulseAudio failed. Automatic retry in 5s.&lt;br&gt;&lt;br&gt;In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Propertiesor default-server in client.conf is misconfigured.&lt;br&gt;This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.&lt;br&gt;If this is the case, then PulseAudio should autospawn again, or if this is not configured you shouldrun start-pulseaudio-x11 manually.</source>
-        <translation type="unfinished"></translation>
+        <translation>De verbinding met PulseAudio is mislukt. Er wordt over 5 seconden een nieuwe poging gedaan.&lt;br&gt;&lt;br&gt;Mogelijk is de optie ‘PULSE_SERVER’ in de venstereigenschappen of ‘default-server’ in client.conf op onjuiste wijze ingesteld.&lt;br&gt;Ook kan het zijn dat PulseAudio gecrasht is en verouderde informatie heeft achtergelaten in het X11-hoofdvenster.&lt;br&gt;Als dit allemaal niet het geval is, dan zou PulseAudio zichzelf moeten kunnen herstarten. In andere gevallen kan dit met behulp van de opdracht ‘start-pulseaudio-x11’.</translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="672"/>
+        <location filename="../pavucontrol.cc" line="671"/>
         <source>Select a specific tab on load.</source>
         <translation>Kies een specifiek tabblad om automatisch te laden.</translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="675"/>
+        <location filename="../pavucontrol.cc" line="674"/>
         <source>Retry forever if pa quits (every 5 seconds).</source>
         <translation>Probeer steeds opnieuw indien pulseaudio stopt (elke 5 seconden).</translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="678"/>
+        <location filename="../pavucontrol.cc" line="677"/>
         <source>Maximize the window.</source>
         <translation>Maximaliseer het venster.</translation>
     </message>
     <message>
-        <location filename="../pavucontrol.cc" line="703"/>
+        <location filename="../pavucontrol.cc" line="702"/>
         <source>Fatal Error: Unable to connect to PulseAudio</source>
         <translation>Fatale fout: kan niet verbinden met PulseAudio</translation>
     </message>
